********************************************************************************
********************************************************************************
* Create analysis data
********************************************************************************
********************************************************************************


********************************************************************************
* Merge sokatper and insper

use "_insper_ecma", clear
merge 1:m persid inlnr using "_sokatper_ecma", keep(matched) nogenerate

drop if forpen == "J"				// drop early pension
drop forpen
drop inlnr

order persid start end

compress

save "_t", replace





********************************************************************************
* Sampling period, right-censoring and duration variables

use "_t", clear

gen job = exit_state == 1
label variable job "== 1 exit to part/full time emp."

gen end_sub = o_program1 if o_pgroup1 == 6		// Date subsidized employment
label variable end_sub "Date subsidized employment"

* Inflow sample period

keep if start <= mdy(12,31,2012) 				

* Right-censoring

gen cdat = mdy(12,31,2012) 	
replace job      = 0 if end > cdat 	
replace end      = cdat if end       > cdat 	
replace end_part = . 	if end_part  > cdat & end_part != .	
replace end_sub  = . 	if end_sub   > cdat & end_sub  != .

replace o_program2 = . if o_program2 >  cdat
replace o_pcode2   = . if o_program2 >  cdat
replace o_pgroup2  = . if o_program2 >  cdat

replace o_program1 = . if o_program1 >  cdat
replace o_pcode1   = . if o_program1 >  cdat
replace o_pgroup1  = . if o_program1 >  cdat

drop cdat

* Duration variables

gen Ts	= d_amu - start
label variable Ts "Treatment duration in days"
gen Tu	= end - start
label variable Tu "Employment duration in days"

replace job = 1        if end_part != .			// Adjust if end with part-time employment
replace end = end_part if end_part != .			
gen C = job == 0
label variable C     "==1 censored, non-full time part time exit"

gen Ts_m	    = mofd(d_amu) - mofd(start)+1	// Monthly variables
label variable Ts_m "Treatment duration in months"
gen Tu_m	    = mofd(end)  - mofd(start)+1	
label variable Tu_m "Employment duration in months"

order persid Tu_m Ts_m Tu Ts job start d_amu exit_state end end_part end_sub
gen W = Ts_m != .			// Training indicator
tab W

replace Ts_m = . if Ts_m > Tu_m & Ts_m != .		// Adjust duration variable if training after exit to part-time employment	
replace Ts   = . if Ts_m == .					// Adjust duration variable if training after exit to part-time employment	
replace W = Ts_m != .							// Training indicator
tab W

replace W = Ts_m != .			// Training indicator
tab W

save "_lr_main_fresh", replace

erase "_t.dta"






********************************************************************************
* Information on previous registration at the PES

use "Leverans\Sokatper2013p", clear
rename dnr2013243 persid
drop if persid == ""
sort persid inskadm utskadm

* Merge episodes by creating start and end dates
gen start = inskadm		

replace start = start[_n-1] if persid == persid[_n-1] & start == utskadm[_n-1] 
bysort persid start: keep if _n == _N
drop inskadm
rename start inskadm

* Keep relevant spells and re-shape

keep persid inskadm utskadm 

drop if utskadm < mdy(1,1,1993) 		// For the analysis period
drop if inskadm > mdy(12,31,1998) 

bysort persid: gen N = _n
sum N
gen max = r(max)
reshape wide inskadm utskadm, i(persid max) j(N)

save "_w", replace

* Merge on to the data

use "_lr_main_fresh", clear
merge m:m persid using "_w", keep(matched using) nogenerate

gen pre_reg0 = 0
gen pre_reg1 = 0
gen pre_reg2 = 0

label variable pre_reg0 "Registration within 180 days before spell"
label variable pre_reg1 "Registration within 365 days before spell"
label variable pre_reg2 "Registration within 2 years before spell"

sum max
local max = r(mean)
drop max

set more off
forvalues s = 1/`max' {
	replace pre_reg0 = 1 if (utskadm`s'+365/2 > start)  & inskadm`s' < start
	replace pre_reg1 = 1 if (utskadm`s'+365 > start)  & inskadm`s' < start
	replace pre_reg2 = 1 if (utskadm`s'+365*2 > start) & inskadm`s' < start
	drop inskadm`s' utskadm`s'
}

save "_lr_main_fresh", replace
	
erase _w.dta	


********************************************************************************
* Add socioeconomic variables and lagged income from Louise


* Merge ind. covariate information

set more off
forvalues y = 1994/2010 {
use "_lr_main_fresh", replace
	keep if y == `y'
	local b = `y'-1

	merge m:1 persid using ind`b', nogenerate keep(matched master)	
	
	if `y' != 1994 append using _tt
	save _tt, replace
}



* Merge lagged income information

forvalues y = 1994/2010 {
	use _tt, replace
	keep if y == `y'
	local b = `y'-1
	merge m:1 persid using inc`b', nogenerate keep(master matched)
	foreach var in loneink akassa soc sys {
		rename `var' `var'_m1	
	}
	local b = `y'-2
	merge m:1 persid using inc`b', nogenerate keep(master matched) keepusing(loneink akassa soc sys)
	foreach var in loneink akassa soc sys {
		rename `var' `var'_m2
	}
	local b = `y'-3
	merge m:1 persid using inc`b', nogenerate keep(master matched) keepusing(loneink akassa soc sys)
	foreach var in loneink akassa soc sys {
		rename `var' `var'_m3
	}
	if `y' != 1994 append using _ttt
	save _ttt, replace
}

* Merge future income information

forvalues y = 1994/2010 {
	use _ttt, replace
	keep if y == `y'
	local c = (2013-`y'+1)
	
	forvalues t = 1/`c' {
		local b = `y'+`t'-1
		merge m:1 persid using inc`b', nogenerate keep(master matched)
		foreach var in loneink akassa soc sys {
			rename `var' `var'_`t'	
		}
	}	
		
	if `y' != 1994 append using _tttt
	save _tttt, replace
}

erase _tt.dta
erase _ttt.dta
erase _tttt.dta

save "_lr_main_fresh2", replace



********************************************************************************
* Covariate restrictions and clean other variables


use "_lr_main_fresh2", clear
	
	gen age = y-birth_year
	keep if age>24 & age<56		// Age-restrictions
	tab W
	drop if dis1 == 1			// Remove disabled participants within the spell
	tab W
	
	gen medel = int(age) < 45 & int(age) > 34
	gen gam   = int(age) > 44
	gen fgymn = edu_lev < 3
	gen gymn  = edu_lev == 3 | edu_lev == 4
	gen egymn = edu_lev > 4
	tab edu_lev
	gen utrikes = origin != 1

	gen sth = lan == 1
	gen gbg = lan == 14
	gen skane = lan == 12
	gen north = lan == 21 | lan == 22 | lan == 23 | lan  == 24 | lan == 25 
	gen south = lan  == 6 | lan  == 7 | lan  == 8 | lan   == 9 | lan == 10 | lan == 13 

	gen child7_15 = child7_10+child11_15
	replace child0_3 = 1 if child0_3 > 1
	replace child4_6 = 1 if child4_6 > 1
	replace child7_15 = 1 if child7_15 > 1
	
	*local controls_list "child7_15 child4_6 child0_3 married loneink* soc* lan utrikes y ui_elig ilok male days_m1 days_m2 days_m3 age medel gam edu_lev fgymn gymn egymn utrikes sth gbg skane north south" 
	*keep `controls_list' persid T* job start end end_part end_sub o_* *_amu exit_state C prep kurs kplamsyk
	*drop  soc* akassa*
	
	foreach var in loneink_m1 soc_m1 loneink_m2 soc_m2 loneink_m3 soc_m3 {
		drop if `var' < 0
		replace `var' = 0 if `var' == .
	}

	forvalues y = 1994/2010 {
		gen y`y' = y == `y'
		label variable y`y'   "== 1 unemployment spell starts `y'"
	}
	
	compress
	
* Keep observations with non-missing for main variables
drop if married == . 
drop if edu_lev == .

* Label variables
label variable fgymn    "== 1 pre high-school"
label variable gymn    "== 1 high-school"
label variable egymn   "== 1 university / college"

label variable utrikes "== 1 foreign born"
label variable sth     "== 1 stockholm"
label variable gbg     "== 1 gothenburg"
label variable skane   "== 1 skane"
label variable north   "== 1 nothern parts"
label variable south   "== 1 southern parts"
label variable medel   "== 1 in ages 35-44" 
label variable gam     "== 1 in ages 44-"

save "_lr_main_fresh3", replace


************************************************************************************
* Create duration outcomes (not used in published version)


use "_lr_main_fresh3", clear
	gen T_firstprog   = mofd(o_program1)- mofd(start)+1
	gen T_firstprog_d = o_program1- start+1
	
	gen Tu_m2 = Tu_m 
	gen Ts_m2 = Ts_m 
	gen C2    = C
	replace Tu_m2 = T_firstprog 	if o_pcode1 == 83 & T_firstprog_d < Tu
	replace C2    = 1               if o_pcode1 == 83 & T_firstprog_d < Tu
	replace Ts_m2 = . 				if o_pcode1 == 83 & T_firstprog_d < Ts
	label variable Ts_m2 "Treatment duration,  cens prep. training"
	label variable Tu_m2 "Employment duration, cens prep. training"
	label variable C2     "==1 censored, cens prep. training"

	gen Tu_m3 = Tu_m 
	gen Ts_m3 = Ts_m 
	gen C3    = C
	replace Tu_m3 = T_firstprog 	if T_firstprog_d < Tu
	replace C3    = 1               if T_firstprog_d < Tu
	replace Ts_m3 = . 				if T_firstprog_d < Ts
	label variable Ts_m3 "Treatment duration,  cens all other programs"
	label variable Tu_m3 "Employment duration, cens all other programs"
	label variable C3     "==1 censored, cens all other programs"

	gen Tu_m4 = Tu_m 
	gen Ts_m4 = Ts_m 
	gen C4    = C
	replace T_firstprog_d = . 		if Ts <= T_firstprog_d 
	replace Tu_m4 = T_firstprog 	if T_firstprog_d < Tu
	replace C4    = 1               if T_firstprog_d < Tu
	replace Ts_m4 = . 				if T_firstprog_d < Ts 
	label variable Ts_m4 "Treatment duration,  cens all but only before AMU"
	label variable Tu_m4 "Employment duration, cens all but only before AMU"
	label variable C4     "==1 censored, cens all other programs"

	gen Tu_m5 = Tu_m 
	gen Ts_m5 = Ts_m 
	gen C5    = C
	replace T_firstprog_d = . 		if Ts <= T_firstprog_d 
	replace Tu_m5 = T_firstprog 	if o_pcode1 == 83 & T_firstprog_d < Tu_m
	replace C5    = 1               if o_pcode1 == 83 & T_firstprog_d < Tu_m
	replace Ts_m5 = . 				if o_pcode1 == 83 & T_firstprog_d < Ts_m
	label variable Ts_m5 "Treatment duration,  cens prep but only before AMU"
	label variable Tu_m5 "Employment duration, cens prep but only before AMU"
	label variable C5     "==1 censored, cens all other programs"
	
	order persid Tu_m* Ts_m* C*
	compress
	
	* Clean some variables
	forvalues y = 4/16 {
		drop soc_`y' akassa_`y' sys_`y' 
	}	
saveold "_lr_main_fresh4_ecma", replace


******************************************************************************	
* Select relevant years and fresh spells

use "_lr_main_fresh4_ecma" if uniform()<1, clear
	keep if y >= 1995 & y <= 1998
	keep if pre_reg0 == 0				// Keep fresh spells only
saveold "_lr_anlysis_ecma", replace

******************************************************************************	
* Clean out variables 
use "_lr_anlysis_ecma", clear
	drop Tu_m2 Tu_m3 Tu_m4 Tu_m5 Ts_m2 Ts_m3 Ts_m4 Ts_m5 C2 C3 C4 C5
	drop p_dat utbniv date_birth birth_year birth_month utbk1
	drop d_gar1 d_gar2 d_gar3 d_fub1 d_fub2 d_fub3 d_amu2 d_amu3 sokatlnr W edu_lev
	drop akassa* soc* sys*
	drop child7_10 child11_15
	drop y1999-y2010
	drop T_firstprog*
saveold "_lr_anlysis_ecma2", replace

* Additional labelelling
label variable male "==1 if male"
label variable age  "age in years"
label variable child0_3  "== 1 child in ages 0-3  years"
label variable child4_6  "== 1 child in ages 4-6  years"
label variable child7_15  "== 1 child in ages 7-15 years"

label variable loneink_m1  "Labor income (SEK) entry - 3 years"
label variable loneink_m1  "Labor income (SEK) entry - 2 years"
label variable loneink_m1  "Labor income (SEK) entry - 1 years"
label variable loneink_1   "Labor income (SEK) entry year"
label variable loneink_2   "Labor income (SEK) entry +1 year"
label variable loneink_3   "Labor income (SEK) entry +2 year"
label variable loneink_4   "Labor income (SEK) entry +3 year"
label variable loneink_5   "Labor income (SEK) entry +4 year"
label variable loneink_6   "Labor income (SEK) entry +5 year"
label variable loneink_7   "Labor income (SEK) entry +6 year"
label variable loneink_8   "Labor income (SEK) entry +7 year"
label variable loneink_9   "Labor income (SEK) entry +8 year"
label variable loneink_10  "Labor income (SEK) entry +9 year"
label variable loneink_11  "Labor income (SEK) entry +10 year"
label variable loneink_12  "Labor income (SEK) entry +11 year"
label variable loneink_13  "Labor income (SEK) entry +12 year"
label variable loneink_14  "Labor income (SEK) entry +13 year"

drop loneink_14-loneink_20

saveold "_lr_anlysis_ecma2", replace

use "_lr_anlysis_ecma2", clear

describe
