********************************************************************************
********************************************************************************
*** Static IPW estimates
********************************************************************************
********************************************************************************


************************************************************************************
* Naive estimator adjusted to the application (not included in final version)

* Input: 1. u  : follow-up year, (year == 0 is program year)
**********************************************************

capture: program drop naive_app
program define naive_app

	local u = `1'
			
	qui {
		* Adjust the used outcome by time to the program
		drop Y
		gen yin = year(start)
		gen min = month(start)
		
		gen yp  = yin				
		gen     mm = min+S-1
		sum S if S != 1000
		local k =  int(r(mean))
		replace mm = min+`k'-1 if S == 1000
		
		replace yp = yp+1  	if mm > 12 
		replace mm = mm-12  if mm > 12 
		replace yp = yp+1  	if mm > 12 
		replace mm = mm-12  if mm > 12
		replace yp = yp+1  	if mm > 12 
		replace mm = mm-12  if mm > 12
				
				gen n = yp-yin+1				// OBS loneink1 is the wage in program year
				sum n
				local a = r(max)
				gen 	Y = loneink_`u'
				forvalues n = 1/`a' {
					local nn = `n'+`u'-1
					replace Y = loneink_`nn' if n == `n'
				}
		drop yin min yp n mm	
		
		* Estimates
		sum Y if W == 1
		gen s1 = r(mean)
		sum Y if W == 0
		gen s0 = r(mean)
		gen est = s1-s0
		drop if _n>1
		keep est s1 s0
	}
end




************************************************************************************
* Static IPW estimator adjusted to the application 

* Input: 1. Follow-up year, (year == 0 is program year)
*		 2. Covariates to adjust for
**********************************************************

capture: program drop naive_ipw_app
program define naive_ipw_app

qui {
	
local u = `1'
macro shift 1
local covs `*'
		
		* Adjust the used outcome by time to the program
		drop Y
		gen yin = year(start)
		gen min = month(start)

		gen yp  = yin				
		gen     mm = min+S-1
		sum S if S != 1000
		local k =  int(r(mean))
		replace mm = min+`k'-1 if S == 1000
			
		replace yp = yp+1  	if mm > 12 
		replace mm = mm-12  if mm > 12 
		replace yp = yp+1  	if mm > 12 
		replace mm = mm-12  if mm > 12
		replace yp = yp+1  	if mm > 12 
		replace mm = mm-12  if mm > 12
				
				gen n = yp-yin+1				// OBS loneink1 is the wage in program year
				sum n
				local a = r(max)
				gen 	Y = loneink_`u'
				forvalues n = 1/`a' {
					local nn = `n'+`u'-1
					replace Y = loneink_`nn' if n == `n'
				}
		drop yin min yp n mm	

		* ATT estimate

		logit W `covs'
		predict _PS
		sum _PS

		gen w1 = 1
		sum w1 if W == 1
		replace w1 = w1*Y/r(sum)
		sum w1 if W == 1
		gen s1 = r(sum)

		gen      w0 = _PS/(1-_PS)
		sum w0 if W == 0
		replace w0 = w0*Y/r(sum)
		sum w0 if W == 0
		gen s0 = r(sum)
		
		gen est = s1-s0
		drop if _n>1
		keep est s1 s0
}

end


**************************************************************
* Estimates: naive (not used in final version) and static estimator

local controls "male medel gam married gymn egymn child7_15 child4_6 child0_3 ui_elig ilok days_m1 days_m2 loneink_m1 loneink_m2 loneink_m3 sth gbg skane north south y1996 y1997 y1998"

set more off
use "_lr_anlysis_ecma" if uniform()<1 | Ts_m !=. , clear
	rename Tu_m T
	rename Ts_m S
	
	drop if S > 12 & S != .			// Ignore treatment after 12 months	
	replace S = 1000 if S == .
	
	drop W
	gen W = S<=T					// Static treatment indicator
save "_temp_o", replace


foreach mod in naive_app naive_ipw_app { 
	forvalues u = 1/10 {
		use "_temp_o", replace
		gen Y = loneink_`u'
		`mod' `u' `controls'
		gen u = `u'
		if `u' != 1 append using res_amu_`mod'
		save res_amu_`mod', replace
	}
	list
}
erase _temp_o.dta


**************************************************************
* Bootstrap replicates

forvalues rep = 1/500 {

local controls "male medel gam married gymn egymn child7_15 child4_6 child0_3 ui_elig ilok days_m1 days_m2 loneink_m1 loneink_m2 loneink_m3 sth gbg skane north south y1996 y1997 y1998"

set more off
use "_samp_`rep'_ecma" if uniform()<0.0001 | Ts_m !=. , clear
	rename Tu_m T
	rename Ts_m S
	
	drop if S > 12 & S != .			// Ignore treatment after 12 months	
	replace S = 1000 if S == .
	
	drop W
	gen W = S<=T					// Static treatment indicator
save "_temp_o", replace


foreach mod in naive_app naive_ipw_app { 
	forvalues u = 1/10 {
		use "_temp_o", replace
		gen Y = loneink_`u'
		`mod' `u' `controls'
		gen u = `u'
		if `u' != 1 append using res_amu_`mod'_`rep'
		save res_amu_`mod'_`rep', replace
	}
	list
}
erase _temp_o.dta

}
