********************************************************************************
********************************************************************************
*** Clean unemployment spell data from the Swedish public employment service
********************************************************************************
********************************************************************************

clear all
set more off


* Remove duplicate data 

use "Leverans\insper2013p", clear		
	bysort dnr2013243 inlnr: drop if _n > 1			
save "Leverans\insper2013p", replace

use "Leverans\insper2013", clear		
	bysort dnr2013243 inlnr: drop if _n > 1			
save "Leverans\insper2013", replace


********************************************************************************
* Clean data from the soktatper register
*******************************************************************************

use "Leverans\Sokatper2013p" if uniform()<1, clear

rename dnr2013243 persid
drop if persid == ""

********************************************************************************
* Divide the program codes ("skat codes) into groups 

// Employment
// Full-time unemployment 
// Part-time work
// Programs for disabled workers
// Training
// Employmen subsidy programs
// Other programs

destring skat, replace

gen g = 0

* Employment	23 		Yrkesfiskare 2001-05		
* Employment	31 		Tillf?ligt arbete 1991-0
* Employment	34 		EU/EES-s?ande 1994-04	
* Employment	41 		Ombytess?ande 1991-07
* Employment	(89) 	Fri? (fri?slediga) 2002-08 2007-01 Under perioden 2002-01-01 ?2002-08-12 kodas dessa personer i skat 75					
* Employment	(91) 	Ej statistikf?s 1991-07 2007-12 Avvecklas fr.o.m. 2007-10		
	
foreach s in 23 31 34 41 89 91 {
	replace g = 1 if skat == `s'
}

replace g = 1 if skat == 75 & inskadm>= mdy(1,1,2002) & inskadm <= mdy(8,12,2002)

* Full_time	11 		Arbetsl? 1991-07 Ny definition 2007-10-01		
* Full_time	(12) 	Arbetsl?a, v?ledningsservice 1991-07 2003-11 Redovisas i skat 11	Ej program	
* Full_time	(13) 	Arbetsl?a, v?tar p?beslutad ?g?d 1995-01 2003-11 Redovisas i skat 11		
* Full_time	14 		Arbetss?ande med f?hinder 1991-07 Tidigare ?vriga inskrivna? Namnbyte och ny definition 2007-10-01.		
* Full_time	76 		F?djupad kartl?gning och v?ledning 2006-01	
* Full_time	96 		Arbetsl?a, felregistrering av beslut 2001-05 Tillf?lig kod		
* Full_time	97 		Arbetsl?a, avbrott/?erkallande av beslut 2001-05 Tillf?lig kod		
* Full_time	98 		Arbetsl?a, slutf?d beslutsperiod 2001-05 Tillf?lig kod		
* Full_time	00
* Full_time	99
		
foreach s in 11 12 13 14 15 96 97 98 76 00 99 {
	replace g = 2 if skat == `s'
}		
		
* Part_time	21 		Deltidsarbetsl?a 1991-07		
* Part_time	22 		Timanst?lda 1996-04		

foreach s in 21 22 {
	replace g = 3 if skat == `s'
}		
	
* Disabled	35 Ombytess?ande Samhall 1997-03	
* Disabled	38 Utvecklingsanst?lning 2006-01		
* Disabled	39 Trygghetsanst?lning 2006-02		
* Disabled	42 L?ebidrag 1995-01		
* Disabled	43 Offentligt skyddat arbete, OSA 1995-01
* Disabled 	71 Arbetslivsinriktad rehabilitering 1991-07 Tidigare Arbetsmarknadsinstitut, AMI		

foreach s in 35 38 39 42 43 71 {
	replace g = 4 if skat == `s'
}		
		
* Training	(64) Datortek 1995-07 2006-12	
* Training	81 Arbetsmarknadsutbildning 1991-07 F?beredande utbildning s?redovisas som egen s?andekategori(skat 83)		
* Training	(82) IT-satsningen 1998-01 2000-03		
* Training	83 F?beredande utbildning 2001-01 Redovisades tidigare i skat 81 (Arbetsmarknadsutbildning)		
* Training	(84) Bristyrkesutbildning f? anst?lda 2003-12 2005-12 Inf?des 2003-07-01. Individerna  skrevs in i skat 81 eller 83		
	
foreach s in 64 82 83 81 84 {
	replace g = 5 if skat == `s'
}			
	
*Subsidy	33   	Nystartsjobb 2007-01		
*Subsidy	36 		s?skilt nystartsjobb			
*Subsidy	(45) 	Individuellt Anst?lningsst? 1998-01 1999-10		
*Subsidy	46 		Start av n?ingsverksamhet 1995-05 Tidigare ?tarta eget?	
*Subsidy	(47) 	Allm?t anst?lningsst? 1999-10 2007-03 Fr.o.m. 2003-01 f? ?en ges till deltidsarbetsl?a		
*Subsidy	(48) 	F?st?kt anst?lningsst? (f? 2-?sinskrivna) 1999-10 2007-04		
*Subsidy	49 		S?skilt anst?lningsst? 2000-11 Namnbyte och ?drade regler 2003-07.		
*Subsidy	(50) 	F?st?kt anst?lningsst? (f? 4-?sinskrivna) 2000-08 2004-05		

foreach s in 33 36 45 46 47 48 49 50 {
	replace g = 6 if skat == `s'
}	

*Other	(54)	Arbetspraktik
*Other	(44) 	Rekryteringsst? 1995-04 1997-12 Ers?ts av Anst?lningsst?,skat 45		
*Other	(44) 	Akademikerjobb 2006-03 2006-12 Tidigare Rekryteringsst?		
*Other	(51) 	Beredskapsarbete 1991-07 1997-12 Ers?ts av Anst?lningsst?, skat 45		
*Other	(51) 	Plusjobb 2006-01 2006-12 Tidigare Beredskapsarbete		
*Other	(52) 	Arbetslivsutveckling, ALU 1993-01 1999-03 Ers?ts av Arbetspraktik, skat 54		
*Other	(53) 	Utbildningsvikariat 1991-07 2006-10 F?ekommer i tv?perioder.Ers?ts av Anst?lningsst?, skat 45, 1997-12. ?ter nyfr.o.m. 2006-01.		
*Other	(54) 	Invandrarpraktik 1994-07 1995-06 Ers?ts av Arbetsplatsintroduktion API, skat 55 54 Arbetspraktik 1999-01 Ers?ter skat 52 (Arbetslivsutveckling) och 55 (Arbetsplatsintroduktion)		
*Other	(55)	Arbetsplatsintroduktion, API 1995-01 1999-02 Ers?ter Invandrarpraktik,skat 54, Akademikerpraktik, skat 62, och Ungdomsintroduktion, skat 63. Ers?ts av Arbetspraktik, skat 54		
*Other	(56) 	Offentligt tillf?ligt arbete, OTA 1996-11 2000-12		
*Other	(57) 	Aktivare anv?dning av arbetsl?hetsers?tning 1997-06 1999-11		
*Other	(58) 	Resursarbete 1997-07 1999-11 		
*Other	59 		Prova-p?plats 2005-05 Beslut tagna mellan 2005-02?005-05 fullf?js i s?andekategori 54 (Invandrarpraktik) 		
*Other	(60) 	Interpraktik 2005-05 2006-12 		
*Other	(62) 	Akademikerpraktik 1993-09 1995-06 Ers?ts av Arbetsplatsintroduktion API, skat 55		
*Other	77 		Anst?lningsst? f? l?gtidssjukskrivna 2007-05		
*Other	78 		Instegsjobb 2007-07 		
*Other	85 		L?lingsplatser 2006-01	
*Other	75 		Projekt med arbetsmarknadspolitisk inriktning 2001-01 Under perioden 2002-01-01 ?2002-08-12 inneh?ler denna skat ?en fri?slediga, s.k. Fri?		
*Other	(72) 	S?skilt introduktions- och uppf?jningsst?, SIUS  1999-01 2001-12 Ingick tidigare i skat 71 (Arbetslivsinriktad rehabilitering)						
*Other	(74) 	Jobbs?ar- och v?ledningsinsatser (utanf? aktivitetsgarantin) 2000-08 2000-10 	
*Other	(61) 	Ungdomspraktik 1991-07 1995-09		
*Other	(63) 	Ungdomsintroduktion 1995-01 1995-06 Ers?ts av Arbetsplatsintroduktion API, skat 55		
*Other	65 		Kommunalt program, ungdomar under 20 ?, KUP 1995-10		
* Praktisk kompetensutveckling (67)

foreach s in 44 51 52 53 54 55 56 57 58 59 60 62 67 77 78 85 75 72 74 61 63 65 {
	replace g = 7 if skat == `s'
}	

* Garanty	66 Ungdomsgaranti f? ungdomar 20- 25 ? 1998-01 Tidigare Utvecklingsgaranti f? ungdomar		
* Garanty 	69 Jobbgarantin f? ungdomar
* Garanty	70 Jobb- och utvecklingsgarantin 2007-07		
* Garanty	73 Aktiviteter inom v?ledning ochplatsf?medling  2000-08 Skat 74 (Jobbs?ar- och v?ledningsinsatser ing? efter 2000-11)		
* Garanty Jobb- och utvecklingsgaranti, sysselsättningsfasen (79) 

foreach s in 66 69 70 73 79 {
	replace g = 8 if skat == `s'
}	

replace g = 2 if skat == 37

save "_t", replace


********************************************************************************
* Construct unemployment spells

drop if g == 1			// Drop employment episodes

replace utskadm = mdy(06,12,2013) if utskadm == .	// Adjust missing end dates

sort persid inskadm utskadm

* Merge episodes by creating start and end dates
gen start = inskadm		
gen end   = utskadm
format start end %td
label variable start "Date spell start"
label variable end "Date spell end"

replace start = start[_n-1] if persid == persid[_n-1] & start <= (utskadm[_n-1]+30) 
save _tt, replace
bysort persid start: keep if _n == _N
keep persid start end
merge 1:m persid start using _tt, nogenerate
erase _tt.dta
sort persid start end inskadm utskadm

* Marker for main spell line
bysort persid start: gen main = 1 if _n == 1

* Test only positive spells
gen t = end-start+1
assert t > 0
replace t = utskadm-inskadm+1
assert t > 0
drop t

* Keep if spell starts with full-time unemployment
gen main_f = main*(g==2)
egen m = total(main_f), by(persid start)
keep if m == 1
drop m main_f

save "_t", replace



******************************************************************************	
* Construct information on type of training (preparatory or vocational)

// Only relevant up until 2007

use  "Leverans\Autb07", clear

rename dnr2013243 persid
keep persid sokatlnr inlnr kplamsyk

gen kurskod1 = substr(kplamsyk,1,1)
gen kurskod2 = substr(kplamsyk,1,2)
gen kurskod3 = substr(kplamsyk,1,3)

gen prep = 0
replace prep = 1 if kurskod1 == "X"

gen kurs = .
replace kurs = 1 if kurskod1 == "X"
label define s 1 "FÖRBEREDANDE", add

foreach n in 213 312 {
	replace kurs = 2 if kurskod3 == "`n'"
}
label define s 2  "IT SYSTEM/DRIFT", add

foreach n in 211 212 214 221 311 313 314 315 321 324 {
	replace kurs = 3 if kurskod3 == "`n'"
}
label define s 3  "TEKNIK/NATURVETENSKAP", add

foreach n in 243 245 246 347 348 {
	replace kurs = 4 if kurskod3 == "`n'"
}
label define s 4  "KULTUR/MEDIA", add

foreach n in 241 242 244 247 248 249 341 342 343 344 345 346 {
	replace kurs = 5 if kurskod3 == "`n'"
}
label define s 5 "EKONOMI/SAMHÄLLSVETENSKAP", add

foreach n in 23 33 {
	replace kurs = 6 if kurskod2 == "`n'"
}
label define s 6 "PEDAGOGIK", add

foreach n in 222 223 322 323 513 {
	replace kurs = 7 if kurskod3 == "`n'"
}
label define s 7 "VÅRD/OMSORG", add

foreach n in 41 {
	replace kurs = 8 if kurskod2 == "`n'"
}
label define s 8 "KONTOR/LAGER", add

foreach n in 421 422 511 514 521 522 {
	replace kurs = 9 if kurskod3 == "`n'"
}
label define s 9 "KUNDSERVICE", add

foreach n in 512 913 {
	replace kurs = 10 if kurskod3 == "`n'"
}
label define s 10 "RESTAURANG", add

foreach n in 71 {
	replace kurs = 11 if kurskod2 == "`n'"
}
label define s 11 "BYGG/ANLÄGGNING", add

foreach n in 72 73 74 {
	replace kurs = 12 if kurskod2 == "`n'"
}
label define s 12 "TILLVERKNING/HANTVERK", add

foreach n in 81 82 {
	replace kurs = 13 if kurskod2 == "`n'"
}
label define s 13 "MASKINOPERATÖRSARBETE", add

foreach n in 83 {
	replace kurs = 14 if kurskod2 == "`n'"
}
label define s 14 "TRANSPORT", add


replace kurs = 15 if kurs == .
label define s 15 "ÖVRIGT", add

label values kurs s
tab kurs, m
tab kurskod3 if kurs == 15

drop kurskod1 kurskod2
bysort persid sokatlnr inlnr: keep if _n == 1
save "_e", replace


*********************************************************
* Add this information and adjust program codes 

use "_t", clear
	merge 1:1 persid sokatlnr inlnr using "_e", keep(master matched) nogenerate
	replace skat = 83 if skat == 81 & prep == 1
	
	tab skat if prep == 1
	drop kplamsyk kurskod3 prep
	replace kurs = . if skat != 81
	label variable kurs "Course code for AMU"
	drop kurs
save "_t", replace		
	
erase _e.dta	
	
*********************************************************
* Create information on training within guarantee programs 

// Based on extract from Ärendefakta

use "aub_fub_job_uga", clear

rename dnr2013243 persid

gen skat = .
replace skat = 73 if atg_beskr == "Aktiviteter inom vägledning och platsförmedling"
replace skat = 1  if atg_beskr == "Aktivitetsgaranti"  
replace skat = 47 if atg_beskr == "Allmänt anställningsstöd"  
replace skat = 71 if atg_beskr == "Arbetslivsinriktad rehabilitering"
replace skat = 71  if atg_beskr == "Arbetslivsintroduktion"
replace skat = 81 if atg_beskr == "Arbetsmarknadsutbildning" 
replace skat = 55  if atg_beskr == "Arbetsplatsintroduktion"
replace skat = 54 if atg_beskr == "Arbetspraktik"
replace skat = 64 if atg_beskr == "Datortek"
replace skat = 89 if atg_beskr == "Friår"
replace skat = 83 if atg_beskr == "Förberedande utbildning"
replace skat = 76  if atg_beskr == "Fördjupad kartläggning- och vägledning"
replace skat = 50 if atg_beskr == "Förstärkt anställningsstöd"
replace skat = 49 if atg_beskr == "Förstärkt särskilt anställningsstöd"
replace skat = 78  if atg_beskr == "Instegsjobb"
replace skat = 1  if atg_beskr == "Intern coach"
replace skat = 70  if atg_beskr == "Jobb- och utvecklingsgarantin"
replace skat = 79  if atg_beskr == "Jobb-och utvecklingsgarantin fas 3"
replace skat = 69  if atg_beskr == "Jobbgaranti för ungdomar"
replace skat = 65 if atg_beskr == "Kommunala ungdomsprogrammet"  
replace skat = 42 if atg_beskr == "Lönebidrag"
replace skat = 33 if atg_beskr == "Nystartsjobb" 
replace skat = 51 if atg_beskr == "Plusjobb"
replace skat = 1 if atg_beskr == "Projekt"
replace skat = 43 if atg_beskr == "Skyddat arbete hos offentlig arbetsgivare"
replace skat = 46 if atg_beskr == "Start av näringsverksamhet"
replace skat = 49 if atg_beskr == "Särskilt anställningsstöd"
replace skat = 36 if atg_beskr == "Särskilt nystartsjobb"
replace skat = 39 if atg_beskr == "Trygghetsanställning"
replace skat = 66 if atg_beskr == "Ungdomsgaranti"
replace skat = 53 if atg_beskr == "Utbildningsvikariat"
replace skat = 38 if atg_beskr == "Utvecklingsanställning"  

tab skat, m	


* Divide programs into groups (based on above)
rename start_dat inskadm
gen g = 0

foreach s in 23 31 34 41 89 91 {
	replace g = 1 if skat == `s'
}
replace g = 1 if skat == 75 & inskadm>= mdy(1,1,2002) & inskadm <= mdy(8,12,2002)

foreach s in 11 12 13 14 15 96 97 98 76 00 99 {
	replace g = 2 if skat == `s'
}		
		
foreach s in 21 22 {
	replace g = 3 if skat == `s'
}		
	
foreach s in 35 38 39 42 43 71 {
	replace g = 4 if skat == `s'
}		
		
foreach s in 64 82 83 81 84 {
	replace g = 5 if skat == `s'
}			
	
foreach s in 33 36 45 46 47 48 49 50 {
	replace g = 6 if skat == `s'
}	

foreach s in 44 51 52 53 54 55 56 57 58 59 60 62 67 77 78 85 75 72 74 61 63 65 {
	replace g = 7 if skat == `s'
}	

foreach s in 66 69 70 73 79 {
	replace g = 8 if skat == `s'
}	
replace g = 2 if skat == 37	
	
rename inskadm start_dat	
	
* Adjust groups for activities without a skat code

replace g = 7  if atg_beskr == "Intern coach"
replace g = 7  if atg_beskr == "Projekt"
replace g = 7  if atg_beskr == "Aktivitetsgaranti" 
	
* Remove "friar"
drop if skat == 89

keep persid start_dat skat g

* Wide format 
bysort persid (start_dat): gen n = _n
drop if n > 15
reshape wide start_dat skat g , i(persid) j(n)

save "_arende", replace



*********************************************************
* Merge on information on programs within quarentee programs to unemployment spells

use "_t", clear
	keep if main == 1
	keep persid start end
	merge m:1 persid using "_arende", keep(master matched)	nogenerate

	forvalues n = 1/15 {
		gen in`n' = 1 if start_dat`n' <= end & start_dat`n' >= start
		replace start_dat`n' =. if missing(in`n')
		replace skat`n'      =. if missing(in`n')
		replace g`n'         =. if missing(in`n')
		drop in`n'
	}
	reshape long start_dat skat g, i(persid start end) j(n)
	keep if 1-missing(start_dat) == 1

	rename start_dat inskadm
	keep persid start end inskadm skat g	
	append using "_t"
	sort persid inskadm
	
	* Remove duplicate information on training
	drop if persid == persid[_n-1] & inskadm == inskadm[_n-1] & skat == skat[_n-1]

save "_t", replace	
	

	
******************************************************************************	
* Create indicators for participation in programs for disabled workers

gen disabled = g == 4
egen dis1 = total(disabled), by(persid start)
replace dis1 = 1 if dis1 > 0
label variable dis1 "= 1 if program for disabled within spell"
egen dis2 = total(disabled), by(persid)
replace dis2 = 1 if dis2 > 0
label variable dis2 "= 1 if ever program for disabled "
drop disabled

drop if g == 4

save "_t", replace

	
*********************************************************
* Create information on vocational training

gen amu = skat == 81

egen n_amu = total(amu), by(persid start)
replace n_amu = . if n_amu == 0
label variable n_amu "No. training episodes within spell"
gen t_amu = utskadm-inskadm+1 if amu == 1
gen d_amu = inskadm if amu == 1

format d_amu end %td

save _tt, replace
keep if amu == 1

bysort persid (d_amu): gen b_amu = _n > 1
label variable b_amu "= 1 if previous participation in training"
bysort persid start: replace b_amu=b_amu[1]

bysort persid start (d_amu): gen n = _n
drop inlnr inskadm utskadm
drop if n > 3

drop sokatlnr

reshape wide d_amu t_amu, i(persid start) j(n)
drop t_amu2 t_amu3
rename (d_amu1 t_amu1) (d_amu t_amu)
label variable d_amu "Date start of training"
label variable t_amu "Time in training (days)"

bysort persid start (end): keep if _n == 1
keep persid start n_amu t_amu* b_amu d_amu*

merge 1:m persid start using _tt, nogenerate
erase _tt.dta

keep if main == 1 | amu != 1
drop amu

order persid start end

save "_t", replace




*********************************************************
* Create information on preparatory training 

use "_t", clear

gen fub = skat == 83
gen d_fub = inskadm if fub == 1
format d_fub end %td

save "_tt", replace

keep if fub == 1

bysort persid start (d_fub): gen n = _n
drop if n > 3
keep persid start d_fub n

reshape wide d_fub, i(persid start) j(n)
label variable d_fub1 "Date first FUB"

merge 1:m persid start using _tt, nogenerate
erase _tt.dta

keep if main == 1 | fub != 1
drop d_fub fub

order persid start end

save "_t", replace



*********************************************************
* Create information on guarantee program episodes

use "_t", clear

gen gar = g == 8
gen d_gar = inskadm if gar == 1
format d_gar %td

save "_tt", replace

keep if gar == 1

bysort persid start (d_gar): gen n = _n
drop if n > 3
keep persid start d_gar n

reshape wide d_gar, i(persid start) j(n)
label variable d_gar1 "Date first guarantee program"

merge 1:m persid start using _tt, nogenerate
erase _tt.dta

keep if main == 1 | gar != 1
drop d_gar gar

order persid start end

save "_tt", replace




*********************************************************
* Create information part-time unemployment 

use "_tt", clear

keep if g == 3
gen end_part = utskadm
label variable end_part "Date part-time job"
format end_part %td
bysort persid start (end): keep if _n == 1

keep persid start end_part
merge 1:m persid start using _tt, nogenerate

order persid start end

keep if main == 1 | g != 3


*********************************************************
* Create information other programs [first two] 

preserve
keep if main == 1
drop inskadm utskadm main g skat
save _tt, replace

restore
drop if g == 2
bysort persid start (end): keep if _n < 3
keep persid start end inskadm skat g
bysort persid start (end): gen nr = _n

rename inskadm o_program
rename skat o_pcode
rename g o_pgroup
reshape wide o_*, i(persid start) j(nr)

merge 1:1 persid start end using _tt, nogenerate		// Merge this infor back on

label variable o_program1 "date first program"
label variable o_pgroup1  "category first program"
label variable o_pcode1   "program code first program"

label variable o_program2 "date second program"
label variable o_pgroup2  "category second program"
label variable o_pcode2   "program code second program"

* Tests time to program, part-time, amu and so on

gen t = end-end_part
assert t >=0
replace t = end_part-start
assert t >=0
foreach var in o_program1 o_program2 {
	replace t = end-`var'
	assert t >=0
	replace t = `var'-start
	assert t >=0
}
drop t

label variable inlnr "spell number"
save "_t", replace
	

	
	
********************************************************************************
* Calculate lagged yearly days in unemployment for full sample

set more off
forvalues y = 1992/2011 {
	use _t, clear
	keep persid start end end_part
	replace end = end_part if end_part != .			// set end data to end_part
	
	drop if start > mdy(12,31,`y')
	drop if end   < mdy(01,01,`y')
	replace start = mdy(01,01,`y') if start < mdy(01,01,`y')
	replace end   = mdy(12,31,`y') if end >   mdy(12,31,`y')
	gen days = end-start+1
	collapse days, by(persid)
	keep persid days
	save days`y', replace
}

********************************************************************************
* Merge info on lagged yearly days in unemployment, last two years

use _t, clear
	gen y = yofd(start)
	drop if y < 1994
save _t, replace

qui {

forvalues y = 1994/2012 {
use _t, clear
	keep if y == `y'
	local b = `y'-1
	merge m:1 persid using days`b', nogenerate keep(master matched)
	foreach var in days {
		rename `var' `var'_m1	
	}	
	
	local b = `y'-2
	merge m:1 persid using days`b', nogenerate keep(master matched)
	foreach var in days {
		rename `var' `var'_m2	
	}	
	
	if `y' != 1994 append using _tt
	save _tt, replace
}
}

replace days_m1 = 0 if days_m1 == .
replace days_m2 = 0 if days_m2 == .

label variable days_m1 "Days in unemployment year -1"
label variable days_m2 "Days in unemployment year -2"

label variable y "Inflow year"
erase _tt.dta
erase _t.dta

save "_sokatper_ecma", replace




********************************************************************************
* Clean insper data
********************************************************************************

use "Leverans\insper2013", clear		
	drop atid akt_dat av_dat intr_dat uttr_dat rehab* gar* ank*	
merge 1:1 dnr2013243 inlnr using "Leverans\insper2013p", keep(matched using) update replace nogenerate
	drop atid aktdm avdm intr_dat upvecka matchbar ersratt_dat studvillkor infoarb* komnr			

rename dnr2013243 persid
drop if persid == ""

bysort persid inlnr: drop if _n > 1	// remove few duplicate data	

// Office and region
label variable kontor "PES office"
label variable lan    "region"
destring lan, replace
drop if lan == 2				
replace lan = 12 if lan == 11

// Origin
gen origin = fodland == ""		

replace origin = 2 if fodland == "01"
foreach l in AD AT BE CA CH DE DK ES FO FR GB GR IE IS IT MC NL NO PT TR US VA {
	replace origin = 2 if fodland == "`l'"
}
foreach l in AL AM AZ BA BG BY CS CZ EE GE HR LT LV MD PL RP RU SI SK UA 04 07 10 13 {
	replace origin = 3 if fodland == "`l'"
}
replace origin = 4 if origin == 0
label variable origin "= 1 Sw = 2 West = 3 East = 4 Other"
drop fodland

// Gender
gen male = koen == "M"			
drop koen

// Search area
gen ilok = iloks == "J"			
label variable ilok "= 1 if wider search area"
drop iloks

// Age
rename pdat date_birth			
label variable date_birth ""
gen birth_year  = year(date_birth)
gen birth_month = month(date_birth)

// Level of education
gen u = substr(utbk,1,1)		
destring u, replace force
destring utbniv, replace

gen education = 0 
replace education = 1 if u == 1 | u == 2 
replace education = 2 if u == 3 | u == 4 
replace education = 3 if u == 5 | u == 6 | u == 7 

tab utbniv

replace education = 1 if utbniv == 1 | utbniv == 2
replace education = 2 if utbniv == 3
replace education = 3 if utbniv == 4 | utbniv == 5 | utbniv == 6 
replace education = 1 if education == 0
label variable education " = 1 no high-scool = 2 High-school = 3 university" 

drop utbk utbsun 
rename u utbk1

// UI-eligibility
gen ui_elig = 1
replace ui_elig = 0 if kasnr == ""
replace ui_elig = 0 if kasnr == "00"
replace ui_elig = 0 if kasnr == "01"
drop kasnr
label variable ui_elig "Eligiable for UI"

// Information on exit (job, education, out of labor force, etc. 
gen exit_state = 0
replace exit_state = 1 if avors == "1" | avors == "2" | avors == "3" 
replace exit_state = 2 if avors == "7" 
replace exit_state = 3 if avors == "L" | avors == "S"  | avors == "4" 
replace exit_state = 4 if avors == "5" | avors == "9"  | avors == "8" 
replace exit_state = 5 if avors == "6" 
replace exit_state = 6 if avors == "" 

label variable exit_state "= 1 work,= 2 edu, =3 dis. work, =4 other, =5 unknown = 6 missing"
drop avors

save "_insper_ecma", replace



