******************************************************************
******************************************************************
* Clean socio-economic data and yearly income measures from population register (Louise)
******************************************************************
******************************************************************

* Socio-economic variables and yearly income measures

set more off
forvalues y = 1990/2013 {
	use "Leverans\louisesys`y'", clear
	
	gen married = civil == "G"
	drop civil
	
	if `y' < 2000 {
		gen hsun2no = substr(hsun,2,1)	
	}
	rename hsun2no edu_lev
		
	destring edu_lev, replace
	label define lev 0 "Unknown" 1 "Pre-high school < 9 years" 2 "Pre-high school 9 years"  ///
					 3 "High-school 2 years" 4 "High-school 3 years" 5 "Univ. Colleg < 3 years"  ///
					6 "Univ. Colleg >= 3 years" 7 "Phd"
	destring edu_lev, replace
    label values edu_lev lev 
	
	if `y' > 1999 {
		gen edu_lev2 = substr(hsun2n,1,1)	
	
	destring edu_lev2, replace
	label define lev2 9 "Unknown" 1 "Pre-high school < 9 years" 2 "Pre-high school 9(10) years"  ///
					 3 "High-school 2 years" 4 "Univ. Colleg < 2 years"  ///
					 5 "Univ. Colleg >= 2 years" 6 "Phd"
    label values edu_lev2 lev2
	label variable edu_lev2 "Level of education"
	}
	if `y' < 2000 {
		gen edu_lev2 =.
	}
	
	if `y' < 1994 {
		replace akassa = akassa +kas
		drop kas
	}
	if `y' > 1993 & `y' < 1998 {
		replace akassa = akassa +kas +kasees
		drop kas kasees
	}
	if `y' == 1998 {
		replace akassa = akassa +kas 
		drop kas 
	}
	
	gen sys = syss == "1"
	drop syss
	rename socbidp1 soc
	replace loneink = loneink*100
	replace akassa  = akassa*100
	replace soc = soc*100
	rename dnr2013243 persid
	bysort persid (loneink): keep if _n == _N
		
	keep persid barn0003 barn1115 barn0406 barn0710 loneink akassa soc married sys edu_lev*
	
	save _l, replace

	* Individual characteristics
	use _l, clear
		keep persid barn* married edu_lev
		label variable married "== 1 if married"
		rename barn0003 child0_3
		label variable child0_3 "no. of children in ages 0-3"
		rename barn0406 child4_6
		label variable child4_6 "no. of children in ages 4-6"
		rename barn0710 child7_10
		label variable child7_10 "no. of children in ages 7-10"
		rename barn1115 child11_15
		label variable child11_15 "no. of children in ages 11-15"
	save "ind`y'", replace
	
	* Income variables
	use _l, clear
		keep persid loneink akassa soc sys
		label variable loneink "Labor income (SEK)"
		label variable akassa  "UI (SEK)"
		label variable soc     "Social assistance (SEK)"
		label variable sys     "== 1 employed in Nov"
		
	save "inc`y'", replace
}

erase _l.dta


* CPI adjust the income measures 
set more off
forvalues t = 1990/2013 {
	use "inc`t'", clear
	sum
	gen cpi = .
	replace cpi = 314.06 if `t' ==  2013
	replace cpi = 314.20 if `t' ==  2012
	replace cpi = 311.43 if `t' ==  2011
	replace cpi = 303.46 if `t' ==  2010
	replace cpi = 299.66 if `t' ==  2009
	replace cpi = 300.61 if `t' ==  2008
	replace cpi = 290.51 if `t' ==  2007
	replace cpi = 284.22 if `t' ==  2006
	replace cpi = 280.4 if `t' ==  2005
	replace cpi = 279.2 if `t' ==  2004
	replace cpi = 278.1 if `t' ==  2003
	replace cpi = 272.8 if `t' ==  2002
	replace cpi = 267.1 if `t' ==  2001
	replace cpi = 260.7 if `t' ==  2000
	replace cpi = 258.1 if `t' ==  1999
	replace cpi = 257.0 if `t' ==  1998
	replace cpi = 257.7 if `t' ==  1997
	replace cpi = 256.0 if `t' ==  1996
	replace cpi = 254.8 if `t' ==  1995
	replace cpi = 248.5 if `t' ==  1994
	replace cpi = 243.2 if `t' ==  1993
	replace cpi = 232.4 if `t' ==  1992
	replace cpi = 227.2 if `t' ==  1991
	replace cpi = 207.8 if `t' ==  1990

	replace loneink = loneink/cpi*260.7
	replace akassa  = akassa/cpi*260.7
	replace soc     = soc/cpi*260.7
	drop cpi 
	save "inc`t'", replace
	sum

}



