************************************************************************
* Table 1: ATET effects of Swedish AMU training on earnings, and comparison of estimators
************************************************************************

set more off

*** Combine dynamic and static IPW estimates

* Variance dynamic estimator 
qui {
use "Bootstrap_results\_res_1_wagg", clear
		save _b_res, replace
		forvalues rep = 2/500 {
			use "Bootstrap_results\_res_`rep'_wagg", clear
			append using _b_res
			save _b_res, replace
		}

		drop if est == 0	
		drop if est > 10000

		egen est_m       = mean(est), by(u)
		gen est_s2       = (est-est_m)^2
		save _u, replace
		collapse (sum) est_s2, by(u)
		gen est_se       = sqrt(est_s2/(500-1))

		merge 1:1 u using "main_results_wagg", nogenerate
		save "main_results_wagg_bse", replace
		*erase _b_res.dta
}
list


use _b_res, clear
sum est if u == 4, detail




* Variance naive and static estimators 


qui {
foreach mod in naive_app naive_ipw_app {
		use "Bootstrap_results\_res_amu_`mod'_1", clear
		save _b_res, replace
		forvalues rep = 2/500 {
			use "Bootstrap_results\_res_amu_`mod'_`rep'", clear
			append using _b_res
			save _b_res, replace
		}

		drop if est == 0		

		egen est_m       = mean(est), by(u)
		gen est_s2       = ((est-est_m)^2)
		collapse (sum) est_s2 (mean) est_m, by(u)
		gen est_se       = sqrt(est_s2/(500-1))

		merge 1:1 u using "res_amu_`mod'", nogenerate
		save "res_amu_`mod'_bse", replace
		erase _b_res.dta
		noi list est est_se
}
}
list


* Covariance dynamic and static

qui {

use "Bootstrap_results\_res_1_wagg", clear
		save _b_res, replace
		forvalues rep = 2/500 {
			use "Bootstrap_results\_res_1_wagg", clear
			append using _b_res
			save _b_res, replace
		}
gen rep = _n	
save _b_res, replace

foreach mod in naive_app naive_ipw_app {
		use "Bootstrap_results\_res_amu_`mod'_1", clear
		save _b_res_`mod', replace
		forvalues rep = 2/500 {
			use "Bootstrap_results\_res_amu_`mod'_`rep'", clear
			append using _b_res_`mod'
			save _b_res_`mod', replace
		}
		gen rep = _n	
		rename est est_`mod'
		save _b_res_`mod', replace
}
				
use _b_res, clear
	merge 1:1 rep using _b_res_naive_app, nogenerate
	merge 1:1 rep using _b_res_naive_ipw_app, nogenerate
save _b_res, replace		

forvalues u = 1/10 {
	use _b_res, clear
	keep if u == `u'

	correlate est est_naive_app, covariance
	return list
	matrix a = r(C)
	gen cov_naive = a[1,2]

	correlate est est_naive_ipw_app, covariance
	return list
	matrix a = r(C)
	gen cov_naive_ipw = a[1,2]

	keep if _n == 1
	keep u cov*
	merge 1:1 u using "main_results_wagg_bse", nogenerate
	keep if u == `u'
if `u' != 1 append using "main_results_wagg_bse_covs"
save "main_results_wagg_bse_covs", replace
	
}

foreach mod in naive_app naive_ipw_app {
		erase _b_res_`mod'.dta
}
erase _b_res.dta

}
list est est_se cov*


*** Create the tables
	
use "main_results_wagg_bse_covs", clear
	keep est u est_se cov*
	gen mod = 0
save _a, replace

local m = 1
foreach mod in naive_app naive_ipw_app  { 
	use "res_amu_`mod'_bse", clear
	gen mod = `m'
	local m = `m'+1
	append using _a
	save _a, replace
}

list
keep est u mod est_se cov*
reshape wide est est_se cov*, i(u) j(mod)
list

// Calculate covariance and test for a difference
gen diff = est0-est2
gen diff_p = (diff/sqrt(est2^2))*100
gen se_diff = sqrt(est_se0^2+est_se2^2-2*cov_naive_ipw0)
gen t = (est0-est2)/se_diff
gen p = ttail(1000,t)*2

gen ut     = "Prog. year"	
forvalues u = 4/10 {
	local c = `u'-1
	replace ut = "Prog. + `c' years" if u == `u'
}					

* Estimates in SEK 1000
replace est0 = est0/1000
replace est1 = est1/1000
replace est2 = est2/1000
replace diff = diff/1000

replace est_se0 = est_se0/1000
replace est_se1 = est_se1/1000
replace est_se2 = est_se2/1000
replace se_diff = se_diff/1000


format est0 est1 est2 diff %9.2f
format est_se0 est_se1 est_se2 se_diff %9.2f
format diff_p %9.0f

list est1 est2 est0  diff* p if u > 3
list est_se* se_diff if u > 3


local tab_name = "amu_tab2_500"

* Print table

	#delimit ;
	listtex using "`tab_name'.tex" if u == 100, replace type rstyle(tabular)   
	headlines(	
	"\begin{table}[h!]"
	"\caption{Effects of Swedish AMU training on earnings, comparison of estimators}"
	"\label{t:`tab_name'}\centering\small"
	"\begin{tabularx}{\textwidth}{l zzzzzz}"
	"\toprule"
    " & Raw & Static IPW & Dynamic IPW & Difference [3]-[2] & Diff. in percent & p-value (Diff.) \\ " 	
    "  & [1] & [2] & [3] & [4] & [5] & [6] \\ " 	
	" \midrule"
	)
	footlines(
	);
	#delimit cr

forvalues u = 4/10 {
		listtex ut est1 est2 est0 diff diff_p  if u == `u', appendto("`tab_name'.tex") type begin("") delimiter("&") end("\\")
    	listtex est_se1 est_se2 est_se0 se_diff 	if u == `u', appendto("`tab_name'.tex") type begin("&(") delimiter(")&(") end(")\\")  

  	}
	
		
	#delimit ;
	listtex if u == 100 , appendto("`tab_name'.tex") type rstyle(tabular)   
	headlines(	
	)
	footlines(
	"\bottomrule"

"\multicolumn{7}{p{0.98\textwidth}}{\footnotesize Note: Outcome labor earnings in SEK. Dynamic IPW is the dynamic IPW estimator introduced in this paper. Raw makes no covariate adjustments and Static IPW is a standard static IPW estimator with normalized weights. Bootstraped
standard errors (99 replications) }"	
	"\end{tabularx}"
	"\end{table}"
	);
	#delimit cr	
	
erase _a.dta	
