****************************************************************************************************
* Long-Run Effects of Dynamically Assigned Treatments: a New Methodology and an Evaluation of Training Effects on earnings
* Participants: Gerard van den Berg and Johan Vikström
****************************************************************************************************

****************************************************************************
* Simulated bias for the dynamic IPW estimator and a static IPW estimator
* Figures C.1-C.4: 
****************************************************************************

set more off
local p_dofiles   = "P:\2013\243\lr_out\lr_out\do-files"
local p_save      = "P:\2013\243\lr_out\lr_out\monte carlo\Results"


*****************************
* Execute simulations
*****************************

cd "`p_dofiles'"

foreach p in 1 2 3 4 {
	shellout C:\Program Files (x86)\Stata11\StataSE-64.exe do mc_run_dynamic_static `p' 1 "`p_dofiles'" "`p_save'"
}


*****************************
* Output figures
*****************************

cd "`p_save'"


* Simulated bias for our dynamic IPW estimator and a static IPW estimator. 
* Model A: baseline treatment rate

forvalues haz 	= 1.5(0.5)4.5 {
	local val = int(`haz'*10)
		
		use mc_naive_ipw_1_10000_hazS`val', replace
		collapse (mean) bias
		gen mod = "static"
		gen hazS  = -`val'/10
		keep mod hazS bias
		save _b, replace 
		
		use dyn_ipw_nojoint_mc_common1_10000_hazS`val', replace
		collapse (mean) bias
		gen mod = "dynamic"
		gen hazS  = -`val'/10
		keep mod hazS bias
		append using _b
					
	if `haz' != 1.5 append using _a
	save _a, replace
}	

reshape wide bias, i(hazS) j(mod) string
twoway (line biasdynamic biasstatic hazS, sort scheme(s2mono) lwidth(medthick medthick medthick medthick medthick)), ///
	ytitle("Bias") xtitle("Treatment rate, {&alpha}s")  ylabel( ,grid ) graphregion(color(white)) plotregion(color(white)) ///
	legend(label(1 "Dynamic IPW") label(2 "Static IPW"))  
graph export "mc_dgp3_fig3.eps", as(eps) replace		
	

	
* Simulated bias for our dynamic IPW estimator and a static IPW estimator. 
*Model B: impact of the covariate on the conditional treatment probability
	
forvalues betaS = 0(0.2)2 {
	local val = int(`betaS'*10)
		
		use mc_naive_ipw_2_10000_betaS`val', replace
		collapse (mean) bias
		gen mod = "static"
		gen betaS  = `val'/10
		keep mod betaS bias
		save _b, replace 
		
		use dyn_ipw_nojoint_mc_common2_10000_betaS`val', replace
		collapse (mean) bias
		gen mod = "dynamic"
		gen betaS  = `val'/10
		keep mod betaS bias
		append using _b
					
	if `betaS' != 0 append using _a
	save _a, replace
}	

reshape wide bias, i(betaS) j(mod) string

twoway (line biasdynamic biasstatic betaS, sort scheme(s2mono) lwidth(medthick medthick medthick medthick medthick)), ///
	ytitle("Bias") xtitle("Covariate impact treatment selection, {&beta}s")  ylabel( ,grid ) graphregion(color(white)) plotregion(color(white)) ///
	legend(label(1 "Dynamic IPW") label(2 "Static IPW"))  
graph export "mc_dgp4_fig3.eps", as(eps) replace		
	
	
* Simulated bias for our dynamic IPW estimator and a static IPW estimator. 
* Model C: correlation between the unobserved characteristics in the exit and long-outcome equations

set more off

forvalues bu = 0(0.2)2 {
	local val = int(`bu'*10)
	di `val'
		
		use mc_naive_ipw_3_10000_bu`val', replace
		collapse (mean) bias
		gen mod = "static"
		gen bu  = `val'/10
		keep mod bu bias
		save _b, replace 
		
		use dyn_ipw_nojoint_mc_common3_10000_bu`val', replace
		collapse (mean) bias
		gen mod = "dynamic"
		gen bu  = `val'/10
		keep mod bu bias
		append using _b
					
			
	if `bu' != 0 append using _a
	save _a, replace
}	


reshape wide bias, i(bu) j(mod) string
twoway (line biasdynamic biasstatic bu, sort scheme(s2mono) lwidth(medthick medthick medthick medthick medthick)), ///
	ytitle("Bias") xtitle("Unobserved correlation, {&beta}u")  ylabel( ,grid ) graphregion(color(white)) plotregion(color(white)) ///
	legend(label(1 "Dynamic IPW") label(2 "Static IPW"))  
graph export "mc_dgp2_fig3.eps", as(eps) replace	
	
	
* Simulated bias for our dynamic IPW estimator and a static IPW estimator. 
* Model D: treatment effect on the long-run outcome	
	
set more off

forvalues bw = 0(2)10 {
	local val = int(`bw'*1)
		
		use mc_naive_ipw_4_10000_bw`val', replace
		collapse (mean) bias
		gen mod = "static"
		gen bw  = `val'
		keep mod bw bias
		save _b, replace 
		
		use dyn_ipw_nojoint_mc_common4_10000_bw`val', replace
		collapse (mean) bias
		gen mod = "dynamic"
		gen bw  = `val'
		keep mod bw bias
		append using _b
					
			
	if `bw' != 0 append using _a
	save _a, replace
}	

	
reshape wide bias, i(bw) j(mod) string

twoway (line biasdynamic biasstatic bw, sort scheme(s2mono) lwidth(medthick medthick medthick medthick medthick)), ///
	ytitle("Bias") xtitle("Treatment effect, {&delta}")  ylabel( ,grid ) graphregion(color(white)) plotregion(color(white)) ///
	legend(label(1 "Dynamic IPW") label(2 "Static IPW"))  
graph export "mc_dgp5_fig3.eps", as(eps) replace		
	
	
