****************************************************************************************************
* Long-Run Effects of Dynamically Assigned Treatments: a New Methodology and an Evaluation of Training Effects on earnings
* Participants: Gerard van den Berg and Johan Vikström
****************************************************************************************************

****************************************************************************
* Table C.1: Simulated bias, size and variance of the dynamic IPW estimator
****************************************************************************

set more 

set more off

local p_dofiles   = "P:\2013\243\lr_out\do-files"
local p_save      = "P:\2013\243\lr_out\monte carlo\Results"
*local p_save      = "C:\Users\johvi757\lr_out\monte carlo\simulation_results"


*****************************
* Execute simulations
*****************************

cd "`p_dofiles'"

foreach p in 0 1 2 3 4 {
	shellout C:\Program Files (x86)\Stata11\StataSE-64.exe do mc_run_properties `p' 1 "`p_dofiles'" "`p_save'"
}


*****************************
* Output table
* Table C.1 Simulated bias, size and variance of the dynamic IPW estimator
*****************************

cd "`p_save'"

* Prepare the data

foreach a in 1000 4000 {
	forvalues b = 0/4 {
		use dyn_ipw_nojoint_se_`b'_`a', clear
		
		egen est_m   = mean(est_boot), by(rep)			
		gen est_s2       = (est_boot-est_m)^2
		collapse (sum) est_s2 (mean) est, by(rep)
		gen est_se    = sqrt(est_s2/(500-1))
		
		* Bias
		gen true = 0
		if `b' == 4 {
			replace est = est-5
		}
		gen bias = (est-true)
		
		* Size
		gen size = abs(est/est_se) >1.96 
				
		* se		
		egen meanest = mean(est)
		gen s2   = (est-meanest)^2
			
		collapse (mean) size bias est_se (sum) s2
		gen   se = sqrt(s2/(2000-1))

		keep size bias se 
		order bias se size 
		
		format bias %9.3f
		format size %9.3f
		format se %9.3f
		
		save a_dyn_ipw_nojoint_se_`b'_`a', replace
	}
}

* Add all results

use a_dyn_ipw_nojoint_se_0_1000, clear
	rename (bias se size) (bias1 se1 size1)
	merge 1:1 _n using a_dyn_ipw_nojoint_se_0_4000, nogenerate	
	gen p = "Baseline model"
	order p
save _a, replace

use a_dyn_ipw_nojoint_se_1_1000, clear
	rename (bias se size) (bias1 se1 size1)
	merge 1:1 _n using a_dyn_ipw_nojoint_se_1_4000, nogenerate	
	gen p = "Unobserved correlation, $\beta_u$=2"
append using _a	
save _a, replace

use a_dyn_ipw_nojoint_se_2_1000, clear
	rename (bias se size) (bias1 se1 size1)
	merge 1:1 _n using a_dyn_ipw_nojoint_se_2_4000, nogenerate	
	gen p = "Treatment rate, $\alpha_s$=-2"
append using _a	
save _a, replace

use a_dyn_ipw_nojoint_se_3_1000, clear
	rename (bias se size) (bias1 se1 size1)
	merge 1:1 _n using a_dyn_ipw_nojoint_se_3_4000, nogenerate	
	gen p = "Treatment selection, $\beta_s$=2"
append using _a	
save _a, replace

use a_dyn_ipw_nojoint_se_4_1000, clear
	rename (bias se size) (bias1 se1 size1)
	merge 1:1 _n using a_dyn_ipw_nojoint_se_4_4000, nogenerate	
	gen p = "Treatment effect, $\delta_s$=5"
append using _a	
save _a, replace

order p
gen n = -_n
sort n
drop n

list
	#delimit ;
	listtex using mc_tab1.tex ,  replace type rstyle(tabular)   
	headlines(	
	"\begin{table}[h!]"
	"\caption{Simulated bias, size and variance of the dynamic IPW estimator}"
	"\label{t:mc_ipw}\centering\footnotesize"
	"\begin{tabularx}{\textwidth}{l zzz zzz }"
	"\toprule"
	" &  		\multicolumn{3}{c}{1000 observations} & \multicolumn{3}{c}{4000 observations}\\" 
	"\cmidrule(lr){2-4} \cmidrule(lr){5-7}  "
	" & bias & se & size & bias & se & size \\" 
    " & [1] & [2] & [3] & [4] & [5] & [6]\\ " 
	" \midrule"
	)
	footlines(
	"\bottomrule"
	"\multicolumn{7}{p{0.98\textwidth}}{\scriptsize Note: Note: IPW estimates with bootstrapped standard errors (500 replications). The data generating processes is described in the text. Size is for 5\% level tests. The results are based on 2000 replications.} "	"\end{tabularx}"
	"\end{table}"
	);
	#delimit cr		
	






