***************************************************************************
*** Monte Carlo Part: Comparison static and dynamic approaches ***********
***************************************************************************

clear all 
set more off
discard

// Run program file	
cd "`3'"
do mc_programs.do	 			    // Run program file	

// Directory for saved results
local place = "`4'"						
cd "`place'"


*********************************************************
*************** Simulation input ***********************
*********************************************************

local N_periods = 12	// # periods in the model 
local N_obs     = 10000	// # observations
local N_sim		= 2000  // # mc replicates
local N_reps	= 0 	// # bootstrap replicates

* General DGP:	hazTu  = f(hazT0 + betaT*X + Vu)			[in the paper: f(-2.5+X+v_u)]
*				hazTS  = f(hazS0 + betaS*X)					[in the paper: f(alpha_s+beta_s*X)]
*				f	   = [1+exp(-h)]^-1
*				Y	   = 100 + bx*X + bw*I(Tu>=Ts)+ bu*Vu + Vy 	
*	    [in the paper: 100 + beta_Y*X + delta*I(Tu>=Ts)+ beta_u*v_u + v_y

* Baseline DGP parameters 
local hazT0 	= -2.5 		// fixed in the paper
local betaT 	= 1			// fixed in the paper

local hazS0 	= -3.0		// alpha_s in the paper
local betaS 	= 1			
	
local bx    	= 1			// beta_y in the paper
local bw        = 0			// delta in the paper
local bu    	= 1			// beta_u in the paper


***************************************************
* DGP1 * Treatment rate: hazS0 = -1.5(.5)-4.5
***************************************************

if `1' == 1 {

set seed 20140128`1'

forvalues haz 	= 1.5(0.5)4.5 {
local val = int(`haz'*10)
local hazS0 = -`haz'

local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt naive_ipw `vars' 
save mc_naive_ipw_`1'_`N_obs'_hazS`val', replace

mc_alt dyn_ipw_nojoint_mc_common `vars' 
save dyn_ipw_nojoint_mc_common`1'_`N_obs'_hazS`val', replace

}
}


***********************************************************************
* DGP2 * Vary X covariate impact - treatment selection, betaS = 0(.2)2
***********************************************************************

if `1' == 2 {

set seed 20140128`1'

forvalues betaS = 0(0.2)2 {
local val = int(`betaS'*10)

local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt naive_ipw `vars' 
save mc_naive_ipw_`1'_`N_obs'_betaS`val', replace

mc_alt dyn_ipw_nojoint_mc_common `vars' 
save dyn_ipw_nojoint_mc_common`1'_`N_obs'_betaS`val', replace

}
}



***************************************************
* DGP3 * Vary unobserved correlation,	bu = 0(.2)2
***************************************************

if `1' == 3 {

set seed 20140128`1'

forvalues bu = 0(0.2)2 {
local val = int(`bu'*10)

local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt naive_ipw `vars' 
save mc_naive_ipw_`1'_`N_obs'_bu`val', replace

mc_alt dyn_ipw_nojoint_mc_common `vars' 
save dyn_ipw_nojoint_mc_common`1'_`N_obs'_bu`val', replace

}
}

***********************************************************************
* DGP4 * Vary treatment effect delta= 0(1)10
***********************************************************************

if `1' == 4 {

set seed 20140128`1'


forvalues bw = 0(2)10 {
local val = `bw'

local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt naive_ipw `vars' 
save mc_naive_ipw_`1'_`N_obs'_bw`val', replace

mc_alt dyn_ipw_nojoint_mc_common `vars' 
save dyn_ipw_nojoint_mc_common`1'_`N_obs'_bw`val', replace

}
}

exit, STATA clear
