***************************************************************************
*** Monte Carlo: Properties dynamic estimator ***********
***************************************************************************

* Run simulations

clear all 
set more off
discard

cd "`3'"
do mc_programs.do	 			    // Run program file	
local place = "`4'"					// Directory
cd "`place'"

*********************************************************
*************** Simulation input ***********************
*********************************************************

local N_periods = 4	    // # periods in the model 
local N_obs     = 1000	// # observations
local N_sim		= 2000  // # mc replicates
local N_reps	= 500 	// # bootstrap replicates

* General DGP:	hazTu  = f(hazT0 + betaT*X + Vu)			[in the paper: f(-2.5+X+v_u)]
*				hazTS  = f(hazS0 + betaS*X)					[in the paper: f(alpha_s+beta_s*X)]
*				f	   = [1+exp(-h)]^-1
*				Y	   = 100 + bx*X + bw*I(Tu>=Ts)+ bu*Vu + Vy 	
*	    [in the paper: 100 + beta_Y*X + delta*I(Tu>=Ts)+ beta_u*v_u + v_y

* Baseline DGP parameters 
local hazT0 	= -2.5 		// fixed in the paper
local betaT 	= 1			// fixed in the paper

local hazS0 	= -3.0		// alpha_s in the paper
local betaS 	= 1			
	
local bx    	= 1			// beta_y in the paper
local bw        = 0			// delta in the paper
local bu    	= 1			// beta_u in the paper


***********************************************************************
* DGP0 * Baseline model
***********************************************************************

if `1' == 0 {

set seed 20140128`1'

local N_obs     = 1000
local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt_boot dyn_ipw_nojoint_mc_common_boot `vars' 
save dyn_ipw_nojoint_se_0_1000, replace

set seed 20140128`1'

local N_obs     = 4000
local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt_boot dyn_ipw_nojoint_mc_common_boot `vars' 
save dyn_ipw_nojoint_se_0_4000, replace


}



***************************************************
* DGP1 * Unobserved correlation,	bu = 2
***************************************************

if `1' == 1 {

set seed 20140128`1'

local bu    	= 2

local N_obs     = 1000
local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt_boot dyn_ipw_nojoint_mc_common_boot `vars' 
save dyn_ipw_nojoint_se_1_1000, replace

set seed 20140128`1'

local bu    	= 2

local N_obs     = 4000
local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt_boot dyn_ipw_nojoint_mc_common_boot `vars' 
save dyn_ipw_nojoint_se_1_4000, replace

}




***************************************************
* DGP3 * Treatment rate, alpa_s = -2
***************************************************

if `1' == 2 {

set seed 20140128`1'

local hazS0 	= -2.0

local N_obs     = 1000
local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt_boot dyn_ipw_nojoint_mc_common_boot `vars' 
save dyn_ipw_nojoint_se_2_1000, replace

set seed 20140128`1'

local hazS0 	= -2.0

local N_obs     = 4000
local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt_boot dyn_ipw_nojoint_mc_common_boot `vars' 
save dyn_ipw_nojoint_se_2_4000, replace

}



***********************************************************************
* DGP4 * Treatment selection, beta_s = 2
***********************************************************************

if `1' == 3 {

set seed 20140128`1'

local betaS 	= 2

local N_obs     = 1000
local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt_boot dyn_ipw_nojoint_mc_common_boot `vars' 
save dyn_ipw_nojoint_se_3_1000, replace

set seed 20140128`1'

local betaS 	= 2

local N_obs     = 4000
local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt_boot dyn_ipw_nojoint_mc_common_boot `vars' 
save dyn_ipw_nojoint_se_3_4000, replace

}

***********************************************************************
* DGP5 * Treatment effect, delta = 5
***********************************************************************

if `1' == 4 {

set seed 20140128`1'

local bw        = 5

local N_obs     = 1000
local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt_boot dyn_ipw_nojoint_mc_common_boot `vars' 
save dyn_ipw_nojoint_se_4_1000, replace

set seed 20140128`1'

local bw        = 5

local N_obs     = 4000
local vars = "`N_sim' `N_reps' `N_obs' `hazT0' `hazS0' `betaT' `betaS' `bu' `bx' `bw' `N_periods'"	

mc_alt_boot dyn_ipw_nojoint_mc_common_boot `vars' 
save dyn_ipw_nojoint_se_4_4000, replace

}







exit, STATA clear
